# charlotte

[![Build Status](https://travis-ci.com/Jack-Kingdom/charlotte.svg?branch=master)](https://travis-ci.com/Jack-Kingdom/charlotte)

Lightweight and expandable spider framework.
![hummer](https://raw.githubusercontent.com/wiki/Jack-Kingdom/charlotte/assets/charlotte-web.jpeg)

## Install
```shell
pip install charlotte
```

## Documentation
Check [wiki](https://github.com/Jack-Kingdom/charlotte/wiki) for details.

## LICENSE
MIT